IoWindow

Struct IoWindow 

pub struct IoWindow<T: Seek> { /* private fields */ }
Seekable I/O adapter that limits operations to a byte range.

For more, see the crate documentation.

Implementations

Source

impl<T: Seek> IoWindow<T>

pub fn new(inner: T, range: impl RangeBounds<u64>) -> Result<IoWindow<T>>

Adapts an object to limit I/O operations within a byte range.

If the current position is earlier than the start of the range, the object is seeked to that start.

A range with an unbounded start (for example, ..1024) is treated as starting at 0.

A range with an unbounded end (for example, 1024..) means the window ends at the end of the stream. Writing past the end of the window is supported if the underlying object can grow its length (some examples include File and Cursor<Vec<u8>>).

Errors

Returns an error if determining the current position or seeking fails.

pub fn into_inner(self) -> T

Consumes this adapter, returning the underlying object.

pub fn get_ref(&self) -> &T

Gets a reference to the underlying object.

pub fn get_mut(&mut self) -> &mut T

Gets a mutable reference to the underlying object.

It is a logic error to seek the object earlier than the start of the window. If you’re not absolutely certain that code using this mutable reference upholds this requirement, call Seek::rewind on this adapter immediately after using the mutable reference.